import request from '@/utils/request'


// 查询挂锁类型-列表
export function listPadLockTypeAPI(query) {
  return request({
    url: '/iscs/lockType/getIsLockTypePage',
    method: 'get',
    params: query
  })
}

// 获取挂锁类型详细信息
export function getPadLockTypeInfoAPI(repairId) {
  return request({
    url: '/iscs/lockType/selectIsLockTypeById?lockTypeId=' + repairId,
    method: 'get'
  })
}

//新增挂锁类型
export function addPadLockTypeAPI(query) {
  return request({
    url: '/iscs/lockType/insertIsLockType',
    method: 'post',
    data: query
  })
}

// 修改挂锁类型信息
export function updatePadLockTypeAPI(data) {
  return request({
    url: '/iscs/lockType/updateIsLockType',
    method: 'post',
    data: data
  })
}

// 删除挂锁类型信息
export function delPadLockTypeAPI(repairId) {
  return request({
    url: '/iscs/lockType/deleteIsLockTypeByLockTypeIds?lockTypeIds='+ repairId,
    method: 'post'

  })
}
