<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
    >
      <el-form-item label="挂锁类型编码" prop="lockTypeCode">
        <el-input
          v-model="queryParams.lockTypeCode"
          placeholder="请输入挂锁类型编码"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="挂锁类型名称" prop="lockTypeName">
        <el-input
          v-model="queryParams.lockTypeName"
          placeholder="请输入挂锁类型名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>

      <el-form-item>
        <el-button
          v-no-more-click
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button
          v-no-more-click
          icon="el-icon-refresh"
          size="mini"
          @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          v-no-more-click
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['mes:md:locktype:add']"
          >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          v-no-more-click
          type="info"
          plain
          icon="el-icon-sort"
          size="mini"
          @click="toggleExpandAll"
          >展开/折叠
        </el-button>
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table
      v-if="refreshTable"
      v-loading="loading"
      :data="deptList"
      row-key="lockTypeId"
      :default-expand-all="isExpandAll"
      :tree-props="{ children: 'children', hasChildren: 'hasChildren' }"
    >
      <el-table-column
        prop="lockTypeCode"
        label="挂锁类型编码"
        width="260"
      ></el-table-column>
      <el-table-column
        prop="lockTypeName"
        label="挂锁类型名称"
        width="260"
      ></el-table-column>
      <el-table-column prop="lockTypeIcon" label="挂锁类型图标" width="260">
        <template slot-scope="scope">
          <img
            style="width: 50px; height: 50px"
            :src="scope.row.lockTypeIcon"
            alt=""
            v-if="scope.row.lockTypeIcon"
          />
          <span v-else>-</span>
        </template>
      </el-table-column>
      <el-table-column prop="lockTypeImg" label="挂锁类型图片" width="260">
        <template slot-scope="scope">
          <img
            style="width: 50px; height: 50px"
            :src="scope.row.lockTypeImg"
            alt=""
            v-if="scope.row.lockTypeImg"
          />
          <span v-else>-</span>
        </template>
      </el-table-column>
      <el-table-column
        prop="lockTypeSpec"
        label="挂锁型号"
        width="260"
      ></el-table-column>
<!--      <el-table-column-->
<!--        prop="lockTypeDescription"-->
<!--        label="挂锁类型描述"-->
<!--        width="260"-->
<!--      ></el-table-column>-->
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            v-no-more-click
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['mes:md:locktype:edit']"
            >修改
          </el-button>
          <el-button
            v-no-more-click
            size="mini"
            type="text"
            icon="el-icon-plus"
            @click="handleAdd(scope.row)"
            v-hasPermi="['mes:md:locktype:add']"
            >新增
          </el-button>

          <el-button
            v-no-more-click
            v-if="scope.row.parentTypeId != 0"
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['mes:md:locktype:remove']"
            >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <!-- 添加或修改锁具机构类型对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-row>
          <el-col :span="18">
            <el-form-item label="父类型" prop="parentTypeId">
              <treeselect
                style="width: 318px"
                v-model="form.parentTypeId"
                :options="deptOptions"
                :normalizer="normalizer"
                placeholder="选择父级"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-form-item label="硬件类型" prop="hardwareTypeId">
          <treeselect
            style="width: 318px"
            v-model="form.hardwareTypeId"
            :options="machinerytypeOptions"
            :normalizer="normalizer1"
            placeholder="请选择硬件类型"
          />
        </el-form-item>
        <el-row>
          <el-col :span="18">
            <el-form-item label="挂锁类型名称" prop="lockTypeName">
              <el-input
                style="width: 318px"
                v-model="form.lockTypeName"
                placeholder="请输入挂锁类型名称"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="19">
            <el-form-item label="挂锁类型编码" prop="lockTypeCode">
              <el-input
                style="width: 318px"
                v-model="form.lockTypeCode"
                placeholder="请输入挂锁类型编码"
              />
            </el-form-item>
          </el-col>
          <el-col :span="3">
            <el-form-item label-width="80">
              <el-switch
                style="width: 170px"
                v-model="autoGenFlag"
                active-color="#13ce66"
                active-text="自动生成"
                @change="handleAutoGenChange(autoGenFlag)"
              >
              </el-switch>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="10">
            <el-form-item label="挂锁型号" prop="lockTypeSpec">
              <el-input
                type="text"
                style="width: 318px"
                v-model="form.lockTypeSpec"
                placeholder="请输入挂锁型号"
              />
            </el-form-item>
<!--            <el-form-item label="挂锁类型描述" prop="lockTypeDescription">-->
<!--              <el-input-->
<!--                type="textarea"-->
<!--                style="width: 318px"-->
<!--                v-model="form.lockTypeDescription"-->
<!--                placeholder="请输入挂锁类型描述"-->
<!--              />-->
<!--            </el-form-item>-->
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="12">
            <el-form-item label="挂锁类型图标" prop="lockTypeIcon">
              <ImageUploadSingle
                :limit="1"
                :value="form.lockTypeIcon"
                :fileSize="5"
                @onUploaded="handleImgUplaoded"
                @onRemoved="handleImgRemoved"
              ></ImageUploadSingle>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="挂锁类型图片" prop="lockTypeImg">
              <ImageUploadSingle
                :limit="1"
                :value="form.lockTypeImg"
                :fileSize="5"
                @onUploaded="handleImgUplaoded1"
                @onRemoved="handleImgRemoved1"
              ></ImageUploadSingle>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button v-no-more-click type="primary" @click="submitForm"
          >确 定</el-button
        >
        <el-button v-no-more-click @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listPadLockTypeAPI,
  getPadLockTypeInfoAPI,
  addPadLockTypeAPI,
  updatePadLockTypeAPI,
  delPadLockTypeAPI,
} from "@/api/mes/padLockType/padLockType";
import Treeselect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";
import { genCode } from "@/api/system/autocode/rule";
import { listHanrwareType } from "@/api/mes/hw/hadrwareType";

export default {
  name: "Dept",
  dicts: ["sys_normal_disable"],
  components: { Treeselect },
  data() {
    return {
      //自动生成编码
      autoGenFlag: false,
      optType: undefined,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      codes: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 地图预览弹框
      dialogVisibleMap: false,
      // 显示搜索条件
      showSearch: true,
      // 表格树数据
      deptList: [],
      // 部门树选项
      deptOptions: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 是否展开，默认全部展开
      isExpandAll: true,
      // 重新渲染表格状态
      refreshTable: true,
      // 查询参数
      queryParams: {
        current: 1,
        size: -1,
        lockTypeCode: null,
        lockTypeName: null,
        lockTypeId: null,
      },
      // 总条数
      total: 0,
      // 表单参数
      form: {
        parentTypeId: 0,
      },
      machinerytypeOptions: [], //硬件类型
      EditId: null, //判断是否是编辑弹框的值
      // 表单校验
      rules: {
        // parentId: [
        //   { required: true, message: '父级不能为空', trigger: 'blur' }
        // ],

        lockTypeCode: [
          { required: true, message: "挂锁类型编号不能为空", trigger: "blur" },
        ],
        lockTypeName: [
          { required: true, message: "挂锁类型名称不能为空", trigger: "blur" },
        ],
      },
    };
  },
  created() {
    this.getList();
    this.getTreeselect();
  },
  methods: {
    /** 查询部门列表 */
    getList() {
      this.loading = true;
      listPadLockTypeAPI(this.queryParams).then((response) => {
        debugger;
        var depts = this.handleTree(
          response.data.records,
          "lockTypeId",
          "parentTypeId",
          "children"
        );
        this.deptList = depts;
        this.loading = false;
      });
    },
    /** 转换部门数据结构 */
    normalizer(node) {
      if (node.children && !node.children.length) {
        delete node.children;
      }
      return {
        id: node.lockTypeId,
        label: node.lockTypeName,
        children: node.children,
      };
    },
    /** 查询挂锁类型下拉树结构 */
    getTreeselect() {
      listHanrwareType().then((response) => {
        debugger;
        this.machinerytypeOptions = [];
        const data = this.handleTree(
          response.data.records,
          "id",
          "parentTypeId"
        )[0];
        // console.log(data, "父类型回显");
        this.machinerytypeOptions.push(data);
      });
    },
    /** 转换设备类型数据结构 */
    normalizer1(node) {
      if (node.children && !node.children.length) {
        delete node.children;
      }
      return {
        id: node.id,
        label: node.hardwareTypeName,
        children: node.children,
      };
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        parentTypeId: undefined,
        lockTypeId: undefined,
        lockTypeName: undefined,
        lockTypeIcon: undefined,
        lockTypeImg: undefined,
        lockTypeDescription: undefined,
        lockTypeCode: undefined,
      };
      this.autoGenFlag = false;
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.current = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.queryParams = {
        current: 1,
        size: -1,
        lockTypeCode: null,
        lockTypeName: null,
        lockTypeId: null,
      };
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 新增按钮操作 */
    handleAdd(row) {
      this.reset();
      if (row != undefined) {
        this.form.parentTypeId = row.lockTypeId;
      } else {
        this.form.parentTypeId = 0;
      }
      this.open = true;
      this.title = "添加挂锁类型";
      listPadLockTypeAPI().then((response) => {
        this.deptOptions = this.handleTree(
          response.data.records,
          "lockTypeId",
          "parentTypeId",
          "children"
        );
        console.log(this.deptOptions, "this.deptOptions");
      });
    },
    /** 展开/折叠操作 */
    toggleExpandAll() {
      this.refreshTable = false;
      this.isExpandAll = !this.isExpandAll;
      this.$nextTick(() => {
        this.refreshTable = true;
      });
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      this.EditId = row.lockTypeId || this.ids;
      getPadLockTypeInfoAPI(row.lockTypeId).then((response) => {
        this.form = response.data;
        if(this.form.parentTypeId==0){
          this.form.parentTypeId=null
        }
        this.open = true;
        this.title = "修改挂锁类型";
      });
      listPadLockTypeAPI().then((response) => {
        this.deptOptions = this.handleTree(
          response.data.records,
          "lockTypeId",
          "parentTypeId",
          "children"
        );
      });
    },

    /** 提交按钮 */
    submitForm: function () {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.lockTypeId != undefined) {
            updatePadLockTypeAPI(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            console.log(this.form, "新增作业区域参数");
            addPadLockTypeAPI(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      this.$modal
        .confirm('是否确认删除编号为"' + row.lockTypeCode + '"的数据项？')
        .then(function () {
          return delPadLockTypeAPI(row.lockTypeId);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    //自动生成编码
    handleAutoGenChange(autoGenFlag) {
      if (autoGenFlag) {
        genCode("LOCK_TYPE_CODE").then((response) => {
          this.form.lockTypeCode = response;
        });
      } else {
        this.form.lockTypeCode = null;
      }
    },
    //图片上传成功
    handleImgUplaoded(imgUrl) {
      console.log(imgUrl, "编辑拿到的图片");
      this.form.lockTypeIcon = imgUrl[0].url;
    },
    //图片移除
    handleImgRemoved(imgUrl) {
      this.form.lockTypeIcon = null;
    },
    //图片上传成功
    handleImgUplaoded1(imgUrl) {
      console.log(imgUrl, "编辑拿到的图片");
      this.form.lockTypeImg = imgUrl[0].url;
    },
    //图片移除
    handleImgRemoved1(imgUrl) {
      this.form.lockTypeImg = null;
    },
  },
};
</script>
